@@ -1354,9 +1354,11 @@ class Trainer():
         if num == -1:
             checkpoints = self.get_checkpoints()
 
-            if exists(checkpoints):
-                name = checkpoints[-1]
-                print(f'continuing from previous epoch - {name}')
+            if not exists(checkpoints):
+                return
+
+            name = checkpoints[-1]
+            print(f'continuing from previous epoch - {name}')
 
         self.steps = name * self.save_every
 
